aboutsummaryrefslogtreecommitdiffstats
path: root/packet-l2tp.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2001-03-30 06:10:54 +0000
committerGuy Harris <guy@alum.mit.edu>2001-03-30 06:10:54 +0000
commit949888c04a7a85b847da144d14bf51eedb5bad94 (patch)
tree7b517fc86bf7ab944a63d61eb54f9c9c8c11df1c /packet-l2tp.c
parente30bc52b6af6cd5975885c4bcd7221d9d9a50650 (diff)
Call the dissector for PPP-in-HDLC-like-framing (RFC 1662) the
"ppp_hdlc" dissector, and call the dissector for "raw" PPP (just RFC 1661, no HDLC encapsulation) the "ppp" dissector. Have the common routine used by both those dissectors take the offset in the tvbuff of the PPP protocol field as an argument, rather than assuming that the protocol field begins at the beginning of the tvbuff, so we don't have to construct a new tvbuff in the PPP-in-HDLC-like-framing dissector. Use the PPP dissector, not the PPP-in-HDLC-like-framing dissector, for PPP over Frame Relay - there's no HDLC header in PPP over Frame Relay, at least according to http://www.cisco.com/univercd/cc/td/doc/product/software/ios120/120newft/120t/120t1/pppframe.htm svn path=/trunk/; revision=3208
Diffstat (limited to 'packet-l2tp.c')
-rw-r--r--packet-l2tp.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/packet-l2tp.c b/packet-l2tp.c
index 13b5a7a931..a5be3a8310 100644
--- a/packet-l2tp.c
+++ b/packet-l2tp.c
@@ -7,7 +7,7 @@
* Laurent Cazalet <laurent.cazalet@mailclub.net>
* Thomas Parvais <thomas.parvais@advalvas.be>
*
- * $Id: packet-l2tp.c,v 1.21 2001/01/25 06:14:14 guy Exp $
+ * $Id: packet-l2tp.c,v 1.22 2001/03/30 06:10:54 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@zing.org>
@@ -261,7 +261,7 @@ static const char *avptypestr[NUM_AVP_TYPES] = {
static gchar textbuffer[200];
-static dissector_handle_t ppp_handle;
+static dissector_handle_t ppp_hdlc_handle;
static void
dissect_l2tp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
@@ -439,7 +439,7 @@ dissect_l2tp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
/* If we have data, signified by having a length bit, dissect it */
if (tvb_offset_exists(tvb, index)) {
next_tvb = tvb_new_subset(tvb, index, -1, proto_length - index);
- call_dissector(ppp_handle, next_tvb, pinfo, tree);
+ call_dissector(ppp_hdlc_handle, next_tvb, pinfo, tree);
}
return;
}
@@ -834,7 +834,7 @@ proto_reg_handoff_l2tp(void)
proto_l2tp);
/*
* Get a handle for the PPP dissector.
*/
- ppp_handle = find_dissector("ppp");
+ ppp_hdlc_handle = find_dissector("ppp_hdlc");
}
@@ -834,7 +834,7 @@ proto_reg_handoff_l2tp(void)
proto_l2tp);
/*
- * Get a handle for the PPP dissector.
+ * Get a handle for the PPP-in-HDLC-like-framing dissector.
*/